from . import GaqHub
from pylons import c


def gaq_setup(account_id, single_push=False):
    c._gaq = GaqHub(account_id, single_push=single_push)
    return c.gaq


def gaq_setAccount(account_id):
    c._gaq.setAccount(account_id)


def gaq_setSinglePush(bool_value):
    c._gaq.setSinglePush(bool_value)


def gaq_trackEvent(track_dict):
    c._gaq.trackEvent(track_dict)


def gaq_setCustomVar(index, name, value, opt_scope=None):
    c._gaq.setCustomVar(index, name, value, opt_scope=opt_scope)


def gaq_setDomainName(domain_name):
    c._gaq.setDomainName(domain_name)


def gaq_setAllowLinker(bool_allow):
    c._gaq.setAllowLinker(bool_allow)


def gaq_addTrans(track_dict):
    c._gaq.addTrans(track_dict)


def gaq_addItem(track_dict):
    c._gaq.addItem(track_dict)


def gaq_trackTrans():
    c._gaq.trackTrans()


def gaq_as_html():
    c._gaq.as_html()



from . import GaqHub
from pyramid.threadlocal import get_current_request


def gaq_setup(account_id, single_push=False, request=None):
    request = request or get_current_request()
    request._gaq = GaqHub(account_id, single_push=single_push)
    return request._gaq


def gaq_setAccount(account_id, request=None):
    request = request or get_current_request()
    request._gaq.setAccount(account_id)


def gaq_setSinglePush(bool_value, request=None):
    request = request or get_current_request()
    request._gaq.setSinglePush(bool_value)


def gaq_trackEvent(track_dict, request=None):
    request = request or get_current_request()
    request._gaq.trackEvent(track_dict)


def gaq_setCustomVar(index, name, value, opt_scope=None, request=None):
    request = request or get_current_request()
    request._gaq.setCustomVar(index, name, value, opt_scope=opt_scope)


def gaq_setDomainName(domain_name, request=None):
    request = request or get_current_request()
    request._gaq.setDomainName(domain_name)


def gaq_setAllowLinker(bool_allow, request=None):
    request = request or get_current_request()
    request._gaq.setAllowLinker(bool_allow)


def gaq_addTrans(track_dict, request=None):
    request = request or get_current_request()
    request._gaq.addTrans(track_dict)


def gaq_addItem(track_dict, request=None):
    request = request or get_current_request()
    request._gaq.addItem(track_dict)


def gaq_trackTrans(request=None):
    request = request or get_current_request()
    request._gaq.trackTrans()


def gaq_as_html(request=None):
    request = request or get_current_request()
    return request._gaq.as_html()



"""gaq_helper installation script.
"""
import os

from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))
README = ''
try:
    README = open(os.path.join(here, "README.md")).read()
    README = README.split("\n\n", 1)[0] + "\n"
except:
    pass

requires = [
    "metadata_utils >=0.0.1",
]

setup(
    name="gaq_hub",
    version="0.0.13",
    description="Lightweight Google Analytics support",
    long_description=README,
    classifiers=[
        "Intended Audience :: Developers",
        "Framework :: Pylons",
        "Framework :: Pyramid",
        "Programming Language :: Python",
        "License :: OSI Approved :: MIT License",
    ],
    keywords="web pylons",
    author="Jonathan Vanasco",
    author_email="jonathan@findmeon.com",
    url="https://github.com/jvanasco/gaq_hub",
    license="MIT",
    py_modules=['gaq_hub'],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    tests_require = requires,
    install_requires = requires,
    test_suite="tests",
)
